@@ -6,9 +6,9 @@ import core_main_registry_app.components.data.api as data_registry_api
 from core_main_app.commons import exceptions as exceptions
 from core_main_app.components.data.models import Data
 from core_main_app.utils.integration_tests.integration_base_test_case import MongoIntegrationBaseTestCase
-from core_main_registry_app.commons.constants import DataStatus
-from fixtures.fixtures import DataRegistryFixtures
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
+from core_main_registry_app.commons.constants import DataStatus
+from tests.components.data.fixtures.fixtures import DataRegistryFixtures
 
 fixture_data = DataRegistryFixtures()
 
